@@ -6,31 +6,31 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	 USA
  */
 /* This module is based on Twm, but has been siginificantly modified
  * by Rob Nation
  */
 /*
- *       Copyright 1988 by Evans & Sutherland Computer Corporation,
- *                          Salt Lake City, Utah
+ *	 Copyright 1988 by Evans & Sutherland Computer Corporation,
+ *			    Salt Lake City, Utah
  *  Portions Copyright 1989 by the Massachusetts Institute of Technology
- *                        Cambridge, Massachusetts
+ *			  Cambridge, Massachusetts
  *
- *                           All Rights Reserved
+ *			     All Rights Reserved
  *
  *    Permission to use, copy, modify, and distribute this software and
- *    its documentation  for  any  purpose  and  without  fee is hereby
- *    granted, provided that the above copyright notice appear  in  all
- *    copies and that both  that  copyright  notice  and  this  permis-
- *    sion  notice appear in supporting  documentation,  and  that  the
+ *    its documentation	 for  any  purpose  and	 without  fee is hereby
+ *    granted, provided that the above copyright notice appear	in  all
+ *    copies and that both  that  copyright  notice  and  this	permis-
+ *    sion  notice appear in supporting	 documentation,	 and  that  the
  *    names of Evans & Sutherland and M.I.T. not be used in advertising
- *    in publicity pertaining to distribution of the  software  without
+ *    in publicity pertaining to distribution of the  software	without
  *    specific, written prior permission.
  *
  *    EVANS & SUTHERLAND AND M.I.T. DISCLAIM ALL WARRANTIES WITH REGARD
@@ -39,7 +39,7 @@
  *    M.I.T. BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL  DAM-
  *    AGES OR  ANY DAMAGES WHATSOEVER  RESULTING FROM LOSS OF USE, DATA
  *    OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
- *    TORTIOUS ACTION, ARISING OUT OF OR IN  CONNECTION  WITH  THE  USE
+ *    TORTIOUS ACTION, ARISING OUT OF OR IN  CONNECTION	 WITH  THE  USE
  *    OR PERFORMANCE OF THIS SOFTWARE.
  */
 
@@ -56,6 +56,9 @@
 #include "libs/PictureUtils.h"
 #include "libs/charmap.h"
 #include "libs/wcontext.h"
+#include "libs/Grab.h"
+#include "libs/Strings.h"
+#include "libs/XResource.h"
 #include "fvwm.h"
 #include "externs.h"
 #include "cursor.h"
@@ -128,8 +131,8 @@ static void delete_client_context(FvwmWindow *fw)
 /*
  *
  *  Procedure:
- *      CaptureOneWindow
- *      CaptureAllWindows
+ *	CaptureOneWindow
+ *	CaptureAllWindows
  *
  *   Decorates windows at start-up and during recaptures
  *
@@ -338,15 +341,15 @@ static void hide_screen(
 /*
  *
  *  Procedure:
- *      MappedNotOverride - checks to see if we should really
- *              put a fvwm frame on the window
+ *	MappedNotOverride - checks to see if we should really
+ *		put a fvwm frame on the window
  *
  *  Returned Value:
- *      1   - go ahead and frame the window
- *      0   - don't frame the window
+ *	1   - go ahead and frame the window
+ *	0   - don't frame the window
  *
  *  Inputs:
- *      w       - the window to check
+ *	w	- the window to check
  *
  */
 
@@ -405,7 +408,7 @@ static void do_recapture(F_CMD_ARGS, Bool fSingle)
 	 */
 	XAllowEvents(dpy, AsyncPointer, CurrentTime);
 	discard_events(
-		ButtonPressMask|ButtonReleaseMask|ButtonMotionMask|\
+		ButtonPressMask|ButtonReleaseMask|ButtonMotionMask|	\
 		PointerMotionMask|KeyPressMask|KeyReleaseMask);
 #ifdef DEBUG_STACK_RING
 	verify_stack_ring_consistency();
@@ -788,6 +791,39 @@ void setup_icon_title_parameters(FvwmWindow *fw, window_style *pstyle)
 	return;
 }
 
+void setup_numeric_vals(FvwmWindow *fw, window_style *pstyle)
+{
+	/****** window shading ******/
+	fw->shade_anim_steps = pstyle->shade_anim_steps;
+
+	/****** snapattraction, snapgrid, paging ******/
+	fw->snap_proximity = pstyle->snap_proximity;
+	fw->snap_mode = pstyle->snap_mode;
+	fw->snap_grid_x = pstyle->snap_grid_x;
+	fw->snap_grid_y = pstyle->snap_grid_y;
+	if (pstyle->flags.has_edge_delay_ms_move)
+	{
+		fw->edge_delay_ms_move = pstyle->edge_delay_ms_move;
+	}
+	else
+	{
+		fw->edge_delay_ms_move = DEFAULT_MOVE_DELAY;
+	}
+	if (pstyle->flags.has_edge_delay_ms_resize)
+	{
+		fw->edge_delay_ms_resize = pstyle->edge_delay_ms_resize;
+	}
+	else
+	{
+		fw->edge_delay_ms_resize = DEFAULT_RESIZE_DELAY;
+	}
+	fw->edge_resistance_move = pstyle->edge_resistance_move;
+	fw->edge_resistance_xinerama_move =
+		pstyle->edge_resistance_xinerama_move;
+
+	return;
+}
+
 static void setup_frame_window(
 	FvwmWindow *fw)
 {
@@ -1663,7 +1699,7 @@ void setup_window_font(
 		if (S_HAS_WINDOW_FONT(SCF(*pstyle)) &&
 		    SGET_WINDOW_FONT(*pstyle) &&
 		    (fw->title_font =
-		     FlocaleLoadFont(dpy, SGET_WINDOW_FONT(*pstyle), "FVWM")))
+		     FlocaleLoadFont(dpy, SGET_WINDOW_FONT(*pstyle), "fvwm")))
 		{
 			SET_USING_DEFAULT_WINDOW_FONT(fw, 0);
 		}
@@ -1707,7 +1743,7 @@ void setup_icon_font(
 	{
 		if (S_HAS_ICON_FONT(SCF(*pstyle)) && SGET_ICON_FONT(*pstyle) &&
 		    (fw->icon_font =
-		     FlocaleLoadFont(dpy, SGET_ICON_FONT(*pstyle), "FVWM")))
+		     FlocaleLoadFont(dpy, SGET_ICON_FONT(*pstyle), "fvwm")))
 		{
 			SET_USING_DEFAULT_ICON_FONT(fw, 0);
 		}
@@ -1817,8 +1853,8 @@ void setup_style_and_decor(
 	setup_icon_background_parameters(fw, pstyle);
 	setup_icon_title_parameters(fw, pstyle);
 
-	/****** window shading ******/
-	fw->shade_anim_steps = pstyle->shade_anim_steps;
+	/****** some numeric values ******/
+	setup_numeric_vals(fw, pstyle);
 
 	/****** GNOME style hints ******/
 	if (!S_DO_IGNORE_GNOME_HINTS(SCF(*pstyle)))
@@ -1845,6 +1881,16 @@ void change_icon_boxes(FvwmWindow *fw, window_style *pstyle)
 
 void setup_frame_size_limits(FvwmWindow *fw, window_style *pstyle)
 {
+	if (SHAS_MIN_WINDOW_SIZE(&pstyle->flags))
+	{
+		fw->min_window_width = SGET_MIN_WINDOW_WIDTH(*pstyle);
+		fw->min_window_height = SGET_MIN_WINDOW_HEIGHT(*pstyle);
+	}
+	else
+	{
+		fw->min_window_width = 0;
+		fw->min_window_height = 0;
+	}
 	if (SHAS_MAX_WINDOW_SIZE(&pstyle->flags))
 	{
 		fw->max_window_width = SGET_MAX_WINDOW_WIDTH(*pstyle);
@@ -1861,38 +1907,22 @@ void setup_frame_size_limits(FvwmWindow *fw, window_style *pstyle)
 
 void setup_placement_penalty(FvwmWindow *fw, window_style *pstyle)
 {
-	int i;
-
 	if (!SHAS_PLACEMENT_PENALTY(&pstyle->flags))
 	{
-		SSET_NORMAL_PLACEMENT_PENALTY(*pstyle, 1);
-		SSET_ONTOP_PLACEMENT_PENALTY(*pstyle, PLACEMENT_AVOID_ONTOP);
-		SSET_ICON_PLACEMENT_PENALTY(*pstyle, PLACEMENT_AVOID_ICON);
-		SSET_STICKY_PLACEMENT_PENALTY(*pstyle, PLACEMENT_AVOID_STICKY);
-		SSET_BELOW_PLACEMENT_PENALTY(*pstyle, PLACEMENT_AVOID_BELOW);
-		SSET_EWMH_STRUT_PLACEMENT_PENALTY(
-			*pstyle, PLACEMENT_AVOID_EWMH_STRUT);
+		pl_penalty_struct *p;
+
+		p = SGET_PLACEMENT_PENALTY_PTR(*pstyle);
+		*p = default_pl_penalty;
 	}
 	if (!SHAS_PLACEMENT_PERCENTAGE_PENALTY(&pstyle->flags))
 	{
-		SSET_99_PLACEMENT_PERCENTAGE_PENALTY(
-			*pstyle, PLACEMENT_AVOID_COVER_99);
-		SSET_95_PLACEMENT_PERCENTAGE_PENALTY(
-			*pstyle, PLACEMENT_AVOID_COVER_95);
-		SSET_85_PLACEMENT_PERCENTAGE_PENALTY(
-			*pstyle, PLACEMENT_AVOID_COVER_85);
-		SSET_75_PLACEMENT_PERCENTAGE_PENALTY(
-			*pstyle, PLACEMENT_AVOID_COVER_75);
-	}
-	for (i = 0; i < 6; i++)
-	{
-		fw->placement_penalty[i] = (*pstyle).placement_penalty[i];
-	}
-	for (i = 0; i < 4; i++)
-	{
-		fw->placement_percentage_penalty[i] =
-			(*pstyle).placement_percentage_penalty[i];
+		pl_percent_penalty_struct *p;
+
+		p = SGET_PLACEMENT_PERCENTAGE_PENALTY_PTR(*pstyle);
+		*p = default_pl_percent_penalty;
 	}
+	fw->pl_penalty = (*pstyle).pl_penalty;
+	fw->pl_percent_penalty = (*pstyle).pl_percent_penalty;
 
 	return;
 }
@@ -2025,6 +2055,19 @@ Bool validate_transientfor(FvwmWindow *fw)
 			FW_W_TRANSIENTFOR(fw) = Scr.Root;
 			return False;
 		}
+		/* Check for transient loops */
+		while (XFindContext(
+			       dpy, FW_W_TRANSIENTFOR(cw), FvwmContext,
+			       (caddr_t *)&cw) != XCNOENT &&
+		       IS_TRANSIENT(cw))
+		{
+			if (FW_W_TRANSIENTFOR(cw) == FW_W(fw) || cw == fw)
+			{
+				/* loop detected, ignore the hint */
+				FW_W_TRANSIENTFOR(fw) = Scr.Root;
+				return False;
+			}
+		}
 	}
 	else if (!XGetWindowAttributes(dpy, w, &wa) ||
 		 wa.map_state != IsViewable)
@@ -2055,7 +2098,7 @@ Bool setup_transientfor(FvwmWindow *fw)
 /*
  *
  *  Procedure:
- *      AddWindow - add a new window to the fvwm list
+ *	AddWindow - add a new window to the fvwm list
  *
  */
 FvwmWindow *AddWindow(
@@ -2089,7 +2132,7 @@ FvwmWindow *AddWindow(
 	fw = tmp;
 
 	/****** Make sure the client window still exists.  We don't want to
-	 * leave an orphan frame window if it doesn't.  Since we now have the
+	 * leave an orphan frame window if it doesn't.	Since we now have the
 	 * server grabbed, the window can't disappear later without having been
 	 * reparented, so we'll get a DestroyNotify for it.  We won't have
 	 * gotten one for anything up to here, however. ******/
@@ -2146,7 +2189,7 @@ FvwmWindow *AddWindow(
 
 	/****** basic style and decor ******/
 	/* If the window is in the NoTitle list, or is a transient, dont
-	 * decorate it.  If its a transient, and DecorateTransients was
+	 * decorate it.	 If its a transient, and DecorateTransients was
 	 * specified, decorate anyway. */
 	setup_transientfor(fw);
 	if (win_opts->flags.is_menu)
@@ -2184,7 +2227,7 @@ FvwmWindow *AddWindow(
 	/*
 	 * Reparenting generates an UnmapNotify event, followed by a MapNotify.
 	 * Set the map state to 0 to prevent a transition back to
-	 * WithdrawnState in HandleUnmapNotify.  Map state gets set corrected
+	 * WithdrawnState in HandleUnmapNotify.	 Map state gets set corrected
 	 * again in HandleMapNotify.
 	 */
 	SET_MAPPED(fw, 0);
@@ -2469,7 +2512,7 @@ FvwmWindow *AddWindow(
 	GNOME_SetWinArea(fw);
 
 	/****** windowshade ******/
-	if (state_args.do_shade)
+	if (state_args.do_shade || SDO_START_SHADED(sflags))
 	{
 		rectangle big_g;
 		rectangle new_g;
@@ -2479,6 +2522,13 @@ FvwmWindow *AddWindow(
 		{
 			state_args.shade_dir = GET_TITLE_DIR(fw);
 		}
+		/* If we've set a style for StartShaded, ensure we override
+		 * the state for it here. -- TA.
+		 */
+		if (SDO_START_SHADED(sflags) && !state_args.do_shade)
+		{
+			state_args.shade_dir = SGET_STARTS_SHADED_DIR(style);
+		}
 		big_g = (IS_MAXIMIZED(fw)) ? fw->g.max : fw->g.frame;
 		new_g = big_g;
 		get_shaded_geometry_with_dir(
@@ -2495,19 +2545,24 @@ FvwmWindow *AddWindow(
 	{
 		/* TK always wants some special treatment: If the window is
 		 * simply mapped, the tk menus come up at funny Y coordinates.
-		 * Tell it it's geometry *again* to work around this problem. */
+		 * Tell it it's geometry *again* to work around this problem.
+		 */
 		SendConfigureNotify(
 			fw, fw->g.frame.x, fw->g.frame.y, fw->g.frame.width,
 			fw->g.frame.height, 0, False);
 	}
-	if (HAS_EWMH_INIT_MAXVERT_STATE(fw) == EWMH_STATE_HAS_HINT ||
-	    HAS_EWMH_INIT_MAXHORIZ_STATE(fw) == EWMH_STATE_HAS_HINT)
+	if (
+		HAS_EWMH_INIT_MAXVERT_STATE(fw) == EWMH_STATE_HAS_HINT ||
+		HAS_EWMH_INIT_MAXHORIZ_STATE(fw) == EWMH_STATE_HAS_HINT)
 	{
 		int h;
 		int v;
 		char cmd[256];
 
-		if (is_function_allowed(F_MAXIMIZE, NULL, fw, True, False))
+		if (
+			is_function_allowed(
+				F_MAXIMIZE, NULL, fw, RQORIG_PROGRAM_US,
+				False))
 		{
 			h = (HAS_EWMH_INIT_MAXHORIZ_STATE(fw) ==
 			     EWMH_STATE_HAS_HINT) ? 100 : 0;
@@ -2527,7 +2582,7 @@ FvwmWindow *AddWindow(
 		    (unsigned int*)&JunkWidth, (unsigned int*)&JunkHeight,
 		    (unsigned int*)&JunkBW, (unsigned int*)&JunkDepth))
 	{
-		/* The window has disappeared somehow.  For some reason we do
+		/* The window has disappeared somehow.	For some reason we do
 		 * not always get a DestroyNotify on the window, so make sure
 		 * it is destroyed. */
 		destroy_window(fw);
@@ -2541,10 +2596,10 @@ FvwmWindow *AddWindow(
 /*
  *
  *  Procedure:
- *      FetchWMProtocols - finds out which protocols the window supports
+ *	FetchWMProtocols - finds out which protocols the window supports
  *
  *  Inputs:
- *      tmp - the fvwm window structure to use
+ *	tmp - the fvwm window structure to use
  *
  */
 void FetchWmProtocols(FvwmWindow *tmp)
@@ -2619,10 +2674,10 @@ void FetchWmProtocols(FvwmWindow *tmp)
 /*
  *
  *  Procedure:
- *      GetWindowSizeHints - gets application supplied size info
+ *	GetWindowSizeHints - gets application supplied size info
  *
  *  Inputs:
- *      tmp - the fvwm window structure to use
+ *	tmp - the fvwm window structure to use
  *
  */
 
@@ -2857,13 +2912,13 @@ void GetWindowSizeHints(FvwmWindow *fw)
 		/*
 		** The math looks like this:
 		**
-		**   minAspectX    maxAspectX
+		**   minAspectX	   maxAspectX
 		**   ---------- <= ----------
-		**   minAspectY    maxAspectY
+		**   minAspectY	   maxAspectY
 		**
 		** If that is multiplied out, this must be satisfied:
 		**
-		**   minAspectX * maxAspectY <=  maxAspectX * minAspectY
+		**   minAspectX * maxAspectY <=	 maxAspectX * minAspectY
 		**
 		** So, what to do if this isn't met?  Ignoring it entirely
 		** seems safest.
@@ -2931,6 +2986,10 @@ void GetWindowSizeHints(FvwmWindow *fw)
 				}
 			}
 		}
+#undef maxAspectX
+#undef maxAspectY
+#undef minAspectX
+#undef minAspectY
 	}
 
 	if (*broken_cause != 0)
@@ -3221,7 +3280,7 @@ void destroy_window(FvwmWindow *fw)
 /*
  *
  *  Procedure:
- *      RestoreWithdrawnLocation
+ *	RestoreWithdrawnLocation
  *
  *  Puts windows back where they were before fvwm took over
  *
@@ -3341,7 +3400,7 @@ void RestoreWithdrawnLocation(
 /*
  *
  *  Procedure:
- *      Reborder - Removes fvwm border windows
+ *	Reborder - Removes fvwm border windows
  *
  */
 void Reborder(void)
