@@ -37,6 +37,13 @@
 #include "libs/fvwmlib.h"
 #include "libs/fvwmsignal.h"
 #include "libs/setpgrp.h"
+#include "libs/Grab.h"
+#include "libs/Parse.h"
+#include "libs/ColorUtils.h"
+#include "libs/Graphics.h"
+#include "libs/wild.h"
+#include "libs/envvar.h"
+#include "libs/ClientMsg.h"
 #include "libs/Picture.h"
 #include "libs/PictureUtils.h"
 #include "libs/FGettext.h"
@@ -2270,9 +2277,10 @@ void CMD_Delete(F_CMD_ARGS)
 {
 	FvwmWindow * const fw = exc->w.fw;
 
-	if (!is_function_allowed(F_DELETE, NULL, fw, True, True))
+	if (!is_function_allowed(F_DELETE, NULL, fw, RQORIG_PROGRAM_US, True))
 	{
 		XBell(dpy, 0);
+
 		return;
 	}
 	if (IS_TEAR_OFF_MENU(fw))
@@ -2284,12 +2292,14 @@ void CMD_Delete(F_CMD_ARGS)
 		send_clientmessage(
 			dpy, FW_W_PARENT(fw), _XA_WM_DELETE_WINDOW,
 			CurrentTime);
+
 		return;
 	}
 	if (WM_DELETES_WINDOW(fw))
 	{
 		send_clientmessage(
 			dpy, FW_W(fw), _XA_WM_DELETE_WINDOW, CurrentTime);
+
 		return;
 	}
 	else
@@ -2681,6 +2691,10 @@ void CMD_PrintInfo(F_CMD_ARGS)
 	{
 		print_styles(verbose);
 	}
+	else if (StrEquals(subject, "ImageCache"))
+	{
+		PicturePrintImageCache(verbose);
+	}
 	else
 	{
 		fvwm_msg(ERR, "PrintInfo",
@@ -2880,22 +2894,54 @@ void CMD_AddTitleStyle(F_CMD_ARGS)
 
 void CMD_PropertyChange(F_CMD_ARGS)
 {
-	char string[256] = "\0";
+	char string[256];
+	char *token;
+	char *rest;
 	int ret;
-	unsigned long argument, data1 = 0, data2 = 0;
+	unsigned long argument;
+	unsigned long data1;
+	unsigned long data2;
 
-	if (action == NULL || action == "\0")
+	/* argument */
+	token = PeekToken(action, &rest);
+	if (token == NULL)
 	{
 		return;
 	}
-	ret = sscanf(
-		action,"%lu %lu %lu %255c", &argument, &data1, &data2, string);
+	ret = sscanf(token, "%lu", &argument);
 	if (ret < 1)
 	{
 		return;
 	}
-	BroadcastPropertyChange(
-		argument, data1, data2, (string == NULL)? "":string);
+	/* data1 */
+	data1 = 0;
+	token = PeekToken(rest, &rest);
+	if (token != NULL)
+	{
+		ret = sscanf(token, "%lu", &data1);
+		if (ret < 1)
+		{
+			rest = NULL;
+		}
+	}
+	/* data2 */
+	data2 = 0;
+	token = PeekToken(rest, &rest);
+	if (token != NULL)
+	{
+		ret = sscanf(token, "%lu", &data2);
+		if (ret < 1)
+		{
+			rest = NULL;
+		}
+	}
+	/* string */
+	memset(string, 0, 256);
+	if (rest != NULL)
+	{
+		ret = sscanf(rest, "%255c", &(string[0]));
+	}
+	BroadcastPropertyChange(argument, data1, data2, string);
 
 	return;
 }
@@ -2982,7 +3028,7 @@ void CMD_DefaultFont(F_CMD_ARGS)
 	{
 		/* Try 'fixed', pass NULL font name */
 	}
-	if (!(new_font = FlocaleLoadFont(dpy, font, "FVWM")))
+	if (!(new_font = FlocaleLoadFont(dpy, font, "fvwm")))
 	{
 		if (Scr.DefaultFont == NULL)
 		{
