@@ -28,12 +28,16 @@
 #include "config.h"
 
 #include <stdio.h>
+#include <X11/Xatom.h>
 
 #include "libs/fvwmlib.h"
+#include "libs/Parse.h"
 #include "libs/PictureBase.h"
 #include "libs/FShape.h"
+#include "libs/ColorUtils.h"
 #include "libs/Picture.h"
 #include "libs/PictureUtils.h"
+#include "libs/Graphics.h"
 #include "libs/PictureGraphics.h"
 #include "libs/FRenderInit.h"
 #include "libs/Strings.h"
@@ -195,7 +199,8 @@ Pixmap get_root_pixmap(Atom prop)
 void update_root_pixmap(Atom prop)
 {
 	static Atom a_rootpix = None;
-	unsigned int w = 0, h = 0;
+	int w = 0;
+	int h = 0;
 	XID dummy;
 	Pixmap pix;
 
@@ -209,8 +214,8 @@ void update_root_pixmap(Atom prop)
 		pix = get_root_pixmap(prop);
 		if (pix && !XGetGeometry(
 			dpy, pix, &dummy, (int *)&dummy, (int *)&dummy,
-			&w, &h, (unsigned int *)&dummy,
-			(unsigned int *)&dummy))
+			(unsigned int *)&w, (unsigned int *)&h,
+			(unsigned int *)&dummy, (unsigned int *)&dummy))
 		{
 			pix = None;
 		}
@@ -220,8 +225,8 @@ void update_root_pixmap(Atom prop)
 		pix = get_root_pixmap(a_rootpix);
 		if (pix && !XGetGeometry(
 			dpy, pix, &dummy, (int *)&dummy, (int *)&dummy,
-			&w, &h, (unsigned int *)&dummy,
-			(unsigned int *)&dummy))
+			(unsigned int *)&w, (unsigned int *)&h,
+			(unsigned int *)&dummy, (unsigned int *)&dummy))
 		{
 			pix = None;
 		}
@@ -493,7 +498,7 @@ static void parse_shape(Window win, colorset_t *cs, int i, char *args,
 	{
 		cs->shape_type = SHAPE_STRETCH;
 	}
-	fpa.mask = 0;
+	fpa.mask = FPAM_NO_ALPHA;
 
 	/* try to load the shape mask */
 	if (!token)
@@ -1093,7 +1098,8 @@ void parse_colorset(int n, char *line)
 
 			if (average_pix == root_pic.pixmap)
 			{
-				int w,h;
+				int w;
+				int h;
 				XID dummy;
 
 				XGrabServer(dpy);
@@ -1420,7 +1426,8 @@ void parse_colorset(int n, char *line)
 	/*
 	 * ---------- change the hilight colour ----------
 	 */
-	if (has_hi_changed || has_bg_changed)
+	if (has_hi_changed ||
+	    (has_bg_changed && !(cs->color_flags & HI_SUPPLIED)))
 	{
 		has_hi_changed = 1;
 		if ((cs->color_flags & HI_SUPPLIED) && hi != NULL)
@@ -1451,7 +1458,8 @@ void parse_colorset(int n, char *line)
 	/*
 	 * ---------- change the shadow colour ----------
 	 */
-	if (has_sh_changed || has_bg_changed)
+	if (has_sh_changed ||
+	    (has_bg_changed && !(cs->color_flags & SH_SUPPLIED)))
 	{
 		has_sh_changed = 1;
 		if ((cs->color_flags & SH_SUPPLIED) && sh != NULL)
@@ -1482,7 +1490,9 @@ void parse_colorset(int n, char *line)
 	/*
 	 * ---------- change the shadow foreground colour ----------
 	 */
-	if (has_fgsh_changed || has_fg_changed || has_bg_changed)
+	if (has_fgsh_changed ||
+	    ((has_fg_changed || has_bg_changed) &&
+	     !(cs->color_flags & FGSH_SUPPLIED)))
 	{
 		has_fgsh_changed = 1;
 		if ((cs->color_flags & FGSH_SUPPLIED) && fgsh != NULL)
