@@ -23,8 +23,8 @@
 #include <X11/Xmd.h>
 
 #include "libs/fvwmlib.h"
-#include "libs/fvwmrect.h"
 #include "libs/FScreen.h"
+#include "libs/Strings.h"
 #include "fvwm.h"
 #include "execcontext.h"
 #include "functions.h"
@@ -128,7 +128,7 @@ int ewmh_NumberOfDesktops(EWMH_CMD_ARGS)
 {
 	int d = ev->xclient.data.l[0];
 
-	/* not a lot of sinification for FVWM */
+	/* not a lot of sinification for fvwm */
 	if (d > 0 && (d <= ewmhc.MaxDesktops || ewmhc.MaxDesktops == 0))
 	{
 		ewmhc.NumberOfDesktops = d;
@@ -173,7 +173,7 @@ int ewmh_CloseWindow(EWMH_CMD_ARGS)
 	{
 		return 0;
 	}
-	if (!is_function_allowed(F_CLOSE, NULL, fw, True, False))
+	if (!is_function_allowed(F_CLOSE, NULL, fw, RQORIG_PROGRAM_US, False))
 	{
 		return 0;
 	}
@@ -185,20 +185,32 @@ int ewmh_CloseWindow(EWMH_CMD_ARGS)
 int ewmh_MoveResizeWindow(EWMH_CMD_ARGS)
 {
 	XConfigureRequestEvent cre;
+	int func;
 
 	if (ev == NULL)
 	{
 		return 0;
 	}
-
-	cre.value_mask = ev->xclient.data.l[0];
-	cre.x = ev->xclient.data.l[1];
-	cre.y = ev->xclient.data.l[2];
-	cre.width = ev->xclient.data.l[3];
-	cre.height = ev->xclient.data.l[4];
-	cre.window = ev->xclient.window;
-
-	events_handle_configure_request(cre, fw, True);
+	if (
+		ev->xclient.data.l[3] == fw->g.normal.width &&
+		ev->xclient.data.l[4] == fw->g.normal.height)
+	{
+		func = F_MOVE;
+	}
+	else
+	{
+		func = F_RESIZE;
+	}
+	if (!is_function_allowed(func, NULL, fw, RQORIG_PROGRAM, False))
+	{
+		cre.value_mask = ev->xclient.data.l[0];
+		cre.x = ev->xclient.data.l[1];
+		cre.y = ev->xclient.data.l[2];
+		cre.width = ev->xclient.data.l[3];
+		cre.height = ev->xclient.data.l[4];
+		cre.window = ev->xclient.window;
+		events_handle_configure_request(cre, fw, True);
+	}
 
 	return 0;
 }
@@ -211,13 +223,14 @@ int ewmh_RestackWindow(EWMH_CMD_ARGS)
 	{
 		return 0;
 	}
-
-	cre.value_mask = CWSibling | CWStackMode;
-	cre.above = ev->xclient.data.l[1];
-	cre.detail = ev->xclient.data.l[2];
-	cre.window = ev->xclient.window;
-
-	events_handle_configure_request(cre, fw, True);
+	if (DO_EWMH_USE_STACKING_HINTS(fw))
+	{
+		cre.value_mask = CWSibling | CWStackMode;
+		cre.above = ev->xclient.data.l[1];
+		cre.detail = ev->xclient.data.l[2];
+		cre.window = ev->xclient.window;
+		events_handle_configure_request(cre, fw, True);
+	}
 
 	return 0;
 }
@@ -373,14 +386,18 @@ int ewmh_MoveResize(EWMH_CMD_ARGS)
 
 	if (move)
 	{
-		if (!is_function_allowed(F_MOVE, NULL, fw, True, False))
+		if (
+			!is_function_allowed(
+				F_MOVE, NULL, fw, RQORIG_PROGRAM_US, False))
 		{
 			return 0;
 		}
 	}
 	else
 	{
-		if (!is_function_allowed(F_RESIZE, NULL, fw, True, False))
+		if (
+			!is_function_allowed(
+				F_RESIZE, NULL, fw, RQORIG_PROGRAM_US, False))
 		{
 			return 0;
 		}
@@ -489,7 +506,8 @@ int ewmh_WMState(EWMH_CMD_ARGS)
 		else
 		{
 			if (!is_function_allowed(
-				    F_MAXIMIZE, NULL, fw, True, False))
+				    F_MAXIMIZE, NULL, fw, RQORIG_PROGRAM_US,
+				    False))
 			{
 				return 0;
 			}
@@ -641,8 +659,10 @@ int ewmh_WMStateHidden(EWMH_CMD_ARGS)
 		    bool_arg == NET_WM_STATE_ADD)
 		{
 			/* iconify */
-			if (!is_function_allowed(
-				    F_ICONIFY, NULL, fw, True, False))
+			if (
+				!is_function_allowed(
+					F_ICONIFY, NULL, fw, RQORIG_PROGRAM_US,
+					False))
 			{
 				return 0;
 			}
