@@ -35,6 +35,10 @@
 #include "libs/fvwmlib.h"
 #include "libs/charmap.h"
 #include "libs/wcontext.h"
+#include "libs/Grab.h"
+#include "libs/Parse.h"
+#include "libs/Strings.h"
+#include "libs/Event.h"
 #include "fvwm.h"
 #include "externs.h"
 #include "cursor.h"
@@ -296,12 +300,6 @@ static Bool DeferExecution(
 	return False;
 }
 
-/* dummies */
-void CMD_Dummy(F_CMD_ARGS)
-{
-	return;
-}
-
 /*
 ** do binary search on func list
 */
@@ -714,7 +712,6 @@ static FvwmFunction *find_complex_function(const char *function_name)
 	{
 		return NULL;
 	}
-
 	func = Scr.functions;
 	while (func != NULL)
 	{
@@ -729,7 +726,6 @@ static FvwmFunction *find_complex_function(const char *function_name)
 	}
 
 	return NULL;
-
 }
 
 /*
@@ -1476,13 +1472,12 @@ void CMD_DestroyFunc(F_CMD_ARGS)
 	FvwmFunction *func;
 	char *token;
 
-	GetNextToken(action,&token);
+	token = PeekToken(action, NULL);
 	if (!token)
 	{
 		return;
 	}
 	func = find_complex_function(token);
-	free(token);
 	if (!func)
 	{
 		return;
@@ -1549,3 +1544,59 @@ void CMD_Plus(F_CMD_ARGS)
 
 	return;
 }
+
+void CMD_EchoFuncDefinition(F_CMD_ARGS)
+{
+	FvwmFunction *func;
+	const func_t *bif;
+	FunctionItem *fi;
+	char *token;
+
+	GetNextToken(action, &token);
+	if (!token)
+	{
+		fvwm_msg(ERR, "EchoFuncDefinition", "Missing argument");
+
+		return;
+	}
+	bif = find_builtin_function(token);
+	if (bif != NULL)
+	{
+		fvwm_msg(
+			INFO, "EchoFuncDefinition",
+			"function '%s' is a built in command", token);
+		free(token);
+
+		return;
+	}
+	func = find_complex_function(token);
+	if (!func)
+	{
+		fvwm_msg(
+			INFO, "EchoFuncDefinition",
+			"function '%s' not defined", token);
+		free(token);
+
+		return;
+	}
+	fvwm_msg(
+		INFO, "EchoFuncDefinition", "definition of function '%s':",
+		token);
+	for (fi = func->first_item; fi != NULL; fi = fi->next_item)
+	{
+		fvwm_msg(
+			INFO, "EchoFuncDefinition", "  %c %s", fi->condition,
+			(fi->action == 0) ? "(null)" : fi->action);
+	}
+	fvwm_msg(INFO, "EchoFuncDefinition", "end of definition");
+	free(token);
+
+	return;
+}
+
+/* dummy commands */
+void CMD_Title(F_CMD_ARGS) { }
+void CMD_TearMenuOff(F_CMD_ARGS) { }
+void CMD_KeepRc(F_CMD_ARGS) { }
+void CMD_Silent(F_CMD_ARGS) { }
+void CMD_Function(F_CMD_ARGS) { }
