@@ -42,12 +42,20 @@
 #endif
 
 #include <X11/Xproto.h>
+#include <X11/Xatom.h>
 
 #include "libs/fvwmlib.h"
+#include "libs/envvar.h"
+#include "libs/Strings.h"
+#include "libs/System.h"
+#include "libs/Grab.h"
+#include "libs/ColorUtils.h"
+#include "libs/Graphics.h"
 #include "libs/FScreen.h"
 #include "libs/FShape.h"
 #include "libs/PictureBase.h"
 #include "libs/PictureUtils.h"
+#include "libs/Fsvg.h"
 #include "libs/FRenderInit.h"
 #include "libs/charmap.h"
 #include "libs/wcontext.h"
@@ -67,7 +75,7 @@
 #include "gnome.h"
 #include "ewmh.h"
 #include "add_window.h"
-#include "fvwmsignal.h"
+#include "libs/fvwmsignal.h"
 #include "stack.h"
 #include "virtual.h"
 #include "session.h"
@@ -527,7 +535,7 @@ char *get_display_name(char *display_name, int screen_num)
 /*
  *
  *  Procedure:
- *      Done - tells FVWM to clean up and exit
+ *      Done - tells fvwm to clean up and exit
  *
  */
 /* if restart is true, command must not be NULL... */
@@ -809,9 +817,9 @@ InstallSignals(void)
 #endif
 #endif
 
-	/* When FVWM restarts, the SIGCHLD handler is automatically reset
+	/* When fvwm restarts, the SIGCHLD handler is automatically reset
 	 * to the default handler. This means that Zombies left over from
-	 * the previous instance of FVWM could still be roaming the process
+	 * the previous instance of fvwm could still be roaming the process
 	 * table if they exited while the default handler was in place.
 	 * We fix this by invoking the SIGCHLD handler NOW, so that they
 	 * may finally rest in peace. */
@@ -1128,13 +1136,7 @@ static void InitVariables(void)
 	Scr.CurrentDesk = 0;
 	Scr.EdgeScrollX = DEFAULT_EDGE_SCROLL * Scr.MyDisplayWidth / 100;
 	Scr.EdgeScrollY = DEFAULT_EDGE_SCROLL * Scr.MyDisplayHeight / 100;
-	Scr.ScrollResistance = DEFAULT_SCROLL_RESISTANCE;
-	Scr.MoveResistance = DEFAULT_MOVE_RESISTANCE;
-	Scr.XiMoveResistance = DEFAULT_XIMOVE_RESISTANCE;
-	Scr.SnapAttraction = DEFAULT_SNAP_ATTRACTION;
-	Scr.SnapMode = DEFAULT_SNAP_ATTRACTION_MODE;
-	Scr.SnapGridX = DEFAULT_SNAP_GRID_X;
-	Scr.SnapGridY = DEFAULT_SNAP_GRID_Y;
+	Scr.ScrollDelay = DEFAULT_SCROLL_DELAY;
 	Scr.OpaqueSize = DEFAULT_OPAQUE_MOVE_SIZE;
 	Scr.MoveThreshold = DEFAULT_MOVE_THRESHOLD;
 	/* ClickTime is set to the positive value upon entering the
@@ -1307,6 +1309,9 @@ static void setVersionInfo(void)
 #endif
 #ifdef HAVE_PNG
 	strcat(support_str, " PNG,");
+#endif
+#ifdef HAVE_RSVG
+	strcat(support_str, " SVG,");
 #endif
 	if (FHaveShapeExtension)
 		strcat(support_str, " Shape,");
@@ -1325,6 +1330,9 @@ static void setVersionInfo(void)
 #ifdef HAVE_XRENDER
 	strcat(support_str, " XRender,");
 #endif
+#ifdef HAVE_XCURSOR
+	strcat(support_str, " XCursor,");
+#endif
 #ifdef HAVE_XFT
 	strcat(support_str, " XFT,");
 #endif
@@ -1380,17 +1388,17 @@ static void SetRCDefaults(void)
 		},
 		{
 			"+ \"&4. ",
-			_("Issue FVWM commands"),
+			_("Issue fvwm commands"),
 			"\" Module FvwmConsole"
 		},
 		{
 			"+ \"&R. ",
-			_("Restart FVWM"),
+			_("Restart fvwm"),
 			"\" Restart"
 		},
 		{
 			"+ \"&X. ",
-			_("Exit FVWM"),
+			_("Exit fvwm"),
 			"\" Quit"
 		},
 		{ "Mouse 1 R A Menu MenuFvwmRoot", "", "" },
@@ -1401,7 +1409,7 @@ static void SetRCDefaults(void)
 		{ "Key Right M A MenuCursorRight", "", "" },
 		{ "Key Up M A MenuMoveCursor -1", "", "" },
 		{ "Key Down M A MenuMoveCursor 1", "", "" },
-		{ "Mouse 1 M A MenuSelectItem", "", "" },
+		{ "Mouse 1 MI A MenuSelectItem", "", "" },
 		/* don't add anything below */
 		{ RC_DEFAULTS_COMPLETE, "", "" },
 		{ "Read "FVWM_DATADIR"/ConfigFvwmDefaults", "", "" },
@@ -1769,8 +1777,8 @@ int main(int argc, char **argv)
 	}
 	g_argv[g_argc] = NULL;
 
-	FlocaleInit(LC_CTYPE, "", "", "FVWM");
-	FGettextInit("fvwm", LOCALEDIR, "FVWM");
+	FlocaleInit(LC_CTYPE, "", "", "fvwm");
+	FGettextInit("fvwm", LOCALEDIR, "fvwm");
 
 	setVersionInfo();
 	/* Put the default module directory into the environment so it can be
@@ -2379,6 +2387,7 @@ int main(int argc, char **argv)
 	Scr.ColorLimit = PictureInitColors(
 		PICTURE_CALLED_BY_FVWM, True, &colorLimitop, True, True);
 
+	Frsvg_init();
 	FShapeInit(dpy);
 	FRenderInit(dpy);
 	Scr.pscreen = XScreenOfDisplay(dpy, Scr.screen);
@@ -2392,6 +2401,7 @@ int main(int argc, char **argv)
 			XA_CARDINAL, 32, PropModeReplace, NULL, 0);
 
 	Scr.FvwmCursors = CreateCursors(dpy);
+	XDefineCursor(dpy, Scr.Root, Scr.FvwmCursors[CRS_ROOT]);
 	/* create a window which will accept the keyboard focus when no other
 	 * windows have it */
 	/* do this before any RC parsing as some GC's are created from this
@@ -2594,7 +2604,7 @@ int main(int argc, char **argv)
 		Done(1, "");       /* does not return */
 
 	default:
-		DBUG("main", "Unknown FVWM run-state");
+		DBUG("main", "Unknown fvwm run-state");
 	}
 
 	exit(0);
