@@ -22,6 +22,7 @@
 
 #include "libs/fvwmlib.h"
 #include "libs/Picture.h"
+#include "libs/Graphics.h"
 #include "libs/PictureGraphics.h"
 #include "libs/Rectangles.h"
 #include "fvwm.h"
@@ -441,9 +442,11 @@ void menuitem_paint(
 
 	off_cs = ST_HAS_MENU_CSET(ms) ? ST_CSET_MENU(ms) : -1;
 	/* Note: it's ok to pass a NULL label to is_function_allowed. */
-	if (!IS_EWMH_DESKTOP_FW(mpip->fw) &&
-	    !is_function_allowed(
-		    MI_FUNC_TYPE(mi), MI_LABEL(mi)[0], mpip->fw, True, False))
+	if (
+		!IS_EWMH_DESKTOP_FW(mpip->fw) &&
+		!is_function_allowed(
+			MI_FUNC_TYPE(mi), MI_LABEL(mi)[0], mpip->fw,
+			RQORIG_PROGRAM_US, False))
 	{
 		gcs = ST_MENU_STIPPLE_GCS(ms);
 		off_gcs = gcs;
