@@ -32,6 +32,8 @@
 #include <fcntl.h>
 #endif
 
+#include "libs/Parse.h"
+#include "libs/Strings.h"
 #include "fvwm.h"
 #include "externs.h"
 #include "cursor.h"
