@@ -27,8 +27,8 @@
 #include "libs/fvwmlib.h"
 #include "libs/FShape.h"
 #include "libs/Colorset.h"
-#include "libs/safemalloc.h"
 #include "libs/PictureBase.h"
+#include "libs/Graphics.h"
 #include "libs/PictureGraphics.h"
 
 /* globals */
@@ -268,21 +268,9 @@ void SetWindowBackgroundWithOffset(
 	else
 	{
 
-		pixmap = CreateBackgroundPixmap(
-			dpy, win, width, height, colorset, depth, gc, False);
-		if (x_off != 0 || y_off != 0)
-		{
-			Pixmap p2;
-
-			p2 = ScrollPixmap(
-				dpy, pixmap, gc, x_off, y_off, width, height,
-				depth);
-			if (p2 != None && p2 != ParentRelative && p2 != pixmap)
-			{
-				XFreePixmap(dpy, pixmap);
-				pixmap = p2;
-			}
-		}
+		pixmap = CreateOffsetBackgroundPixmap(
+			dpy, win, x_off, y_off, width, height, colorset,
+			depth, gc, False);
 		if (pixmap)
 		{
 			XSetWindowBackgroundPixmap(dpy, win, pixmap);
@@ -361,7 +349,7 @@ void GetWindowBackgroundPixmapSize(
 	}
 }
 
-/* create a pixmap suitable for plonking on the background of a part of a 
+/* create a pixmap suitable for plonking on the background of a part of a
  * window */
 Pixmap CreateOffsetBackgroundPixmap(
 	Display *dpy, Window win, int x, int y, int width, int height,
@@ -597,6 +585,20 @@ Pixmap CreateOffsetBackgroundPixmap(
 			height, gc);
 	}
 
+	if (x != 0 || y != 0)
+	{
+		Pixmap p2;
+
+		p2 = ScrollPixmap(
+			dpy, pixmap, gc, x, y, width, height,
+			depth);
+		if (p2 != None && p2 != ParentRelative && p2 != pixmap)
+		{
+			XFreePixmap(dpy, pixmap);
+			pixmap = p2;
+		}
+	}
+
 	return pixmap;
 }
 
