@@ -28,6 +28,7 @@
 #include "Colorset.h"
 #include "FRenderInit.h"
 #include "FRenderInterface.h"
+#include "Graphics.h"
 #include "PictureGraphics.h"
 #include "PictureUtils.h"
 #include "FImage.h"
@@ -956,6 +957,7 @@ void PGraphicsRenderPixmaps(
 	t_fra.added_alpha_percent = 100;
 	t_fra.tint_percent = 0;
 	t_fra.mask = 0;
+	t_fra.tint = None;
 
 	if (fra)
 	{
