@@ -25,6 +25,7 @@
 #include <X11/Xlib.h>
 #include <fvwmlib.h>
 #include "FRenderInit.h"
+#include "XError.h"
 
 #define USE_GET_ERROR_TEXT 1
 #ifndef USE_GET_ERROR_TEXT
@@ -42,8 +43,8 @@ void PrintXErrorAndCoredump(Display *dpy, XErrorEvent *error, char *MyName)
 	msg[255] = 0;
 #ifdef USE_GET_ERROR_TEXT
 	/* can't call this from within an error handler! */
-	/* DV (21-Nov-2000): Well, actually we *can* call it in an error handler
-	 * since it does not trigger a protocol request. */
+	/* DV (21-Nov-2000): Well, actually we *can* call it in an error
+	 * handler since it does not trigger a protocol request. */
 	if (error->error_code >= FirstExtensionError)
 	{
 		suc = FRenderGetErrorText(error->error_code, msg);
@@ -69,8 +70,8 @@ void PrintXErrorAndCoredump(Display *dpy, XErrorEvent *error, char *MyName)
 		error->request_code, request_name(error->request_code));
 	fprintf(stderr, "   Minor opcode of failed request:  %d \n",
 		error->minor_code);
-	/* error->resourceid may be uninitialised. This is no proble since we are
-	 * dumping core anyway. */
+	/* error->resourceid may be uninitialised. This is no proble since we
+	 * are dumping core anyway. */
 	fprintf(stderr, "   Resource id of failed request:  0x%lx \n",
 		error->resourceid);
 
@@ -103,7 +104,6 @@ static char *error_names[] = {
 	"BadImplementation",
 };
 
-
 static char *error_name(unsigned char code)
 {
 	if (code == 0 || code > (sizeof(error_names) / sizeof(char *)))
@@ -238,7 +238,6 @@ static char *code_names[] = {
 	"GetModifierMapping",
 };
 
-
 static char *request_name(unsigned char code)
 {
 	if (code == 0 || code > (sizeof(code_names) / sizeof(char *)))
