@@ -38,9 +38,7 @@
 
 #include <unistd.h>
 #include <ctype.h>
-#include <stdlib.h>
 #include <stdio.h>
-#include <strings.h>	/* strncasecmp() */
 
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
@@ -52,6 +50,7 @@
 #include "libs/fvwmlib.h"
 #include "libs/Rectangles.h"
 #include "libs/FShape.h"	/* FShapesSupported */
+#include "libs/Graphics.h"
 #include "FvwmButtons.h"
 #include "misc.h" /* ConstrainSize() */
 #include "icons.h" /* ConfigureIconWindow() */
@@ -519,17 +518,13 @@ void RedrawButton(button_info *b, int draw, XEvent *pev)
 				False);
 			if (cs >= 0)
 			{
-				SetRectangleBackground(Dpy, MyWindow,
-					clip.x, clip.y, clip.width,
-					clip.height, &Colorset[cs],
-					Pdepth, NormalGC);
+				SetClippedRectangleBackground(
+					Dpy, MyWindow, x, y, BW, BH, &clip,
+					&Colorset[cs],Pdepth, NormalGC);
 			}
 			else if (b->flags.b_Back &&
 				!UberButton->c->flags.b_Colorset)
 			{
-				gcv.background = b->bc;
-				XChangeGC(Dpy,NormalGC,GCBackground,
-					&gcv);
 				XFillRectangle(Dpy, MyWindow, NormalGC,
 					clip.x, clip.y, clip.width,
 					clip.height);
@@ -576,8 +571,7 @@ void RedrawButton(button_info *b, int draw, XEvent *pev)
 				}
 				if (buttonTitle(b))
 				{
-					DrawTitle(b, shapeMask, transGC, NULL,
-						True);
+					DrawTitle(b, shapeMask, transGC, NULL);
 				}
 				FShapeCombineMask(Dpy, MyWindow, FShapeBounding,
 					0, 0, shapeMask, FShapeSet);
@@ -588,9 +582,15 @@ void RedrawButton(button_info *b, int draw, XEvent *pev)
 	/* ------------------------------------------------------------------ */
 
 	title = buttonTitle(b);
-	if (cleaned && title)
+	if (cleaned)
 	{
-		DrawTitle(b,MyWindow,NormalGC,pev,False);
+		gcv.foreground = fc;
+		gcv.background = bc;
+		XChangeGC(Dpy, NormalGC, GCForeground | GCBackground, &gcv);
+		if (title)
+		{
+			DrawTitle(b, MyWindow, NormalGC, pev);
+		}
 	}
 
 	if (title == NULL && b->flags.b_Panel &&
@@ -691,8 +691,7 @@ void RedrawButton(button_info *b, int draw, XEvent *pev)
 /**
 *** Writes out title.
 **/
-void DrawTitle(
-	button_info *b,Window win,GC gc, XEvent *pev, Bool do_not_modify_fg)
+void DrawTitle(button_info *b,Window win,GC gc, XEvent *pev)
 {
 	int BH;
 	int ix,iy,iw,ih;
@@ -702,8 +701,6 @@ void DrawTitle(
 	char *s = NULL;
 	int just=justify&b_TitleHoriz; /* Left, center, right */
 	XGCValues gcv;
-	unsigned long gcm;
-	int cset;
 	XRectangle clip;
 	Region region = None;
 	FvwmPicture *pic;
@@ -720,26 +717,11 @@ void DrawTitle(
 	if (!s || !Ffont)
 		return;
 
-	cset = buttonColorset(b);
-	gcm = 0;
-	if (do_not_modify_fg == False)
-	{
-		gcm |= GCForeground;
-		if (cset >= 0)
-		{
-			gcv.foreground = Colorset[cset].fg;
-		}
-		else
-		{
-			gcv.foreground = buttonFore(b);
-		}
-	}
 	if (Ffont->font)
 	{
 		gcv.font = Ffont->font->fid;
-		gcm |= GCFont;
+		XChangeGC(Dpy, gc, GCFont, &gcv);
 	}
-	XChangeGC(Dpy,gc,gcm,&gcv);
 
 	pic = buttonIcon(b);
 	bIconFlagSet = iconFlagSet(b);
