@@ -11,11 +11,11 @@
 
 #include <errno.h>
 
-#include <libs/Module.h>
-#include <libs/fvwmlib.h>
-#include <fvwm/fvwm.h>
-#include <libs/vpacket.h>
-#include <libs/fvwm_sys_stat.h>
+#include "libs/Module.h"
+#include "libs/fvwmlib.h"
+#include "fvwm/fvwm.h"
+#include "libs/vpacket.h"
+#include "libs/fvwm_sys_stat.h"
 
 #ifndef HAVE_STRERROR
 extern char *sys_errlist[];
@@ -35,4 +35,4 @@ extern char *sys_errlist[];
 #endif
 
 
-char * fifos_get_default_name();
+char * fifos_get_default_name(void);
