@@ -48,8 +48,10 @@
 #undef M_ERROR /* Solaris fix */
 #endif
 
-#include <libs/Module.h>
-#include <libs/fvwmlib.h>
+#include "libs/Module.h"
+#include "libs/fvwmlib.h"
+#include "libs/Parse.h"
+#include "libs/Strings.h"
 
 /*
  * fvwm includes:
