@@ -51,6 +51,10 @@
 #include "libs/Colorset.h"
 #include "libs/Flocale.h"
 #include "libs/fvwmsignal.h"
+#include "libs/Grab.h"
+#include "libs/Parse.h"
+#include "libs/Strings.h"
+#include "libs/System.h"
 
 #include "fvwm/fvwm.h"
 #include "FvwmPager.h"
@@ -310,11 +314,7 @@ int main(int argc, char **argv)
     }
 
   x_fd = XConnectionNumber(dpy);
-  PictureInitCMap(dpy);
-  FScreenInit(dpy);
-  AllocColorset(0);
-  FShapeInit(dpy);
-  FRenderInit(dpy);
+  flib_init_graphics(dpy);
 
   Scr.screen = DefaultScreen(dpy);
   Scr.Root = RootWindow(dpy, Scr.screen);
