@@ -40,8 +40,9 @@
 #include "libs/fvwmlib.h"
 #include "libs/FScreen.h"
 #include "libs/FShape.h"
-#include <libs/Module.h>
+#include "libs/Module.h"
 #include "libs/Colorset.h"
+#include "libs/Graphics.h"
 #include "fvwm/fvwm.h"
 #include "libs/PictureGraphics.h"
 #include "FvwmPager.h"
@@ -148,7 +149,6 @@ static void do_scroll(int sx, int sy, Bool do_send_message,
 	static int psx = 0;
 	static int psy = 0;
 	static int messages_sent = 0;
-	static char *self_message = NULL;
 	char command[256];
 	psx+=sx;
 	psy+=sy;
@@ -167,21 +167,14 @@ static void do_scroll(int sx, int sy, Bool do_send_message,
 	{
 		sprintf(command, "Scroll %dp %dp", psx, psy);
 		SendText(fd, command, 0);
-		if (self_message == NULL)
-		{
-			self_message = (char *)safemalloc(sizeof(char)*
-							  (strlen(MyName)+ 23));
-			sprintf(self_message, "SendToModule %s ScrollDone",
-				MyName);
-		}
 		messages_sent++;
-		SendText(fd, self_message, 0);
+		SendText(fd, "Send_Reply ScrollDone", 0);
 		psx = 0;
 		psy = 0;
 	}
 }
 
-void HandleScrollDone()
+void HandleScrollDone(void)
 {
 	do_scroll(0, 0, True, True);
 }
@@ -230,7 +223,7 @@ static void CalcGeom(PagerWindow *t, int win_w, int win_h,
   virt2 = Scr.VWidth - 1 - virt;
   edge2 = (virt2 * win_w) / Scr.VWidth;
 
-  /* then mirror if back to get the real coordinate */
+  /* then mirror it back to get the real coordinate */
   edge2 = win_w - 1 - edge2;
 
   /* Calculate the mini-window's width by subtracting its LHS
@@ -2206,25 +2199,28 @@ void MoveResizePagerView(PagerWindow *t, Bool do_force_redraw)
 
 void MoveStickyWindows(void)
 {
-  PagerWindow *t;
+	PagerWindow *t;
 
-  t = Start;
-  while(t!= NULL)
-  {
-    if(((IS_ICONIFIED(t))&&(IS_ICON_STICKY_ACROSS_DESKS(t)))||
-       (IS_STICKY_ACROSS_DESKS(t)))
-    {
-      if(t->desk != Scr.CurrentDesk)
-      {
-	ChangeDeskForWindow(t,Scr.CurrentDesk);
-      }
-      else
-      {
-	MoveResizePagerView(t, True);
-      }
-    }
-    t = t->next;
-  }
+	t = Start;
+	while (t!= NULL)
+	{
+		if (
+			(IS_ICONIFIED(t) && IS_ICON_STICKY_ACROSS_DESKS(t)) ||
+		        IS_STICKY_ACROSS_DESKS(t) ||
+			(IS_ICONIFIED(t) && IS_ICON_STICKY_ACROSS_PAGES(t)) ||
+		        IS_STICKY_ACROSS_PAGES(t))
+		{
+			if (t->desk != Scr.CurrentDesk)
+			{
+				ChangeDeskForWindow(t,Scr.CurrentDesk);
+			}
+			else
+			{
+				MoveResizePagerView(t, True);
+			}
+		}
+		t = t->next;
+	}
 }
 
 void Hilight(PagerWindow *t, int on)
@@ -3306,7 +3302,7 @@ char *GetBalloonLabel(const PagerWindow *pw,const char *fmt)
 
 
 /* -- ric@giccs.georgetown.edu */
-void UnmapBalloonWindow ()
+void UnmapBalloonWindow (void)
 {
   XUnmapWindow(dpy, Scr.balloon_w);
   BalloonView = None;
