@@ -1,5 +1,5 @@
 /* -*-c-*- */
-/* vim:ts=8:shiftwidth=8: */
+/* vim: set ts=8 shiftwidth=8: */
 
 #ifndef FvwmProxy_h
 #define FvwmProxy_h
@@ -9,7 +9,6 @@
 #include <signal.h>
 #include <fcntl.h>
 #include <sys/wait.h>
-#include <sys/time.h>
 #include <ctype.h>
 
 #include <X11/Xlib.h>
