@@ -16,9 +16,11 @@
 
 #include "config.h"
 
+#include "libs/fvwmlib.h"
+#include "libs/ColorUtils.h"
+#include "libs/Graphics.h"
 #include "Tools.h"
 
-
 /*
  * Fonction pour VDipstick
  * Cration d'une jauge verticale
